@@ -33,7 +33,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.127';
+$VERSION = '0.129';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -2118,7 +2118,7 @@ Sim::OPT::Interlinear
   # As a Perl function:
     interlinear( "./configfile.pl", "./sourcefile.csv", "./obtainedmetamodel.csv" );
   # or as a script, from the command line:
-  ./Interlinear.pm . "" ./SOURCEFILE
+  perl ./Interlinear.pm . "" ./SOURCEFILE
   # (note the dot and <"">).
   # or, again, from the command line, for beginning with a dialogue question:
   interlinear interstart
@@ -2196,7 +2196,7 @@ This dataseries can be used by OPT for the optimization of one or more blocks. T
 
 The number of computations required for the creation of a metamodel in OPT increases exponentially with the number of instances in the metamodel. To make the increase linear, a limit has to be set for the size of the net of instances taken into account in the computations for gradients and for points. The variables in the configuration files controlling those limits are "$limit_checkgrades" and "$limit_checkpoints". By default they are both set to 10000. If a null value ("") is specified for them, no limit is assumed.
 
-To call Interlinear as a Perl function:
+To call Interlinear as a Perl function (best strategy):
 use Sim::OPT::Interlinear;
 interlinear( "./configfile.pl", "./sourcefile.csv", "./obtainedmetamodel.csv" );
 "configfile.pl" is the configuration file. If that file is an empty file, Interlinear will assume the defaults.
